@@ -1,3 +1,4 @@
+import os
 from argparse import ArgumentParser
 from dataclasses import dataclass
 from typing import List
@@ -27,15 +28,23 @@ class Arguments:
             help="split song in multiple songs based on timestamps (youtube video description)",
             action="store_true",
         )
+        parser.add_argument(
+            "--cover",
+            help='cover path like "~/Images/cover1.jpg"',
+        )
 
         args = parser.parse_args(argv)
         self.url = args.url
         self.artists = args.artists or []
         self.album = args.album
         self.split = args.split
+        self.cover = args.cover
 
     def check(self):
         """
         Checks the value and compatibility of arguments.
         """
-        # Nothing todo yet
+        if self.cover and not os.path.isfile(self.cover):
+            raise Exception(
+                f"Cover not found ! You put '{self.cover}' (current dir is '{os.getcwd()}')"
+            )
