@@ -26,6 +26,9 @@ class FilesManager:
             f["album"] = self.args.album
             if track_number:
                 f["tracknumber"] = track_number
+            if self.args.cover:
+                with open(self.args.cover, "rb") as cover_file:
+                    f["artwork"] = cover_file.read()
             f.save()
             dest_dir = "./{}/{}".format(
                 " X ".join(self.args.artists) or UNKNOWN,
